<?php
$bookmark_url = Horde::url('redirect.php')->add('b', $bookmark->id);
$target = $GLOBALS['prefs']->getValue('show_in_new_window') ? '_blank' : '';
if ($bookmark->http_status == 'error') {
    $status = 'error.png';
} elseif ($bookmark->http_status == '') {
    $status = '';
} else {
    $status = substr($bookmark->http_status, 0, 1) . 'xx.png';
}
?>
<table width="100%" cellspacing="0">
 <tr>
  <td valign="top" width="43">
   <?php if ($status) echo Horde::img('http/' . $status) ?>
   <?php echo Horde::img(Trean::getFavicon($bookmark), '', 'class="trean-favicon"', '') ?>
  </td>

  <td valign="top">
   <?php echo Horde::link($bookmark_url, '', '', $target) ?><?php echo htmlspecialchars($bookmark->url) ?></a><?php echo (empty($bookmark->description) ? '' : ' - <small>' . htmlspecialchars($bookmark->description) . '</small>') ?>
   <small>(<?php echo $bookmark->clicks ?> <?php echo ($bookmark->clicks == 1 ? _("click") : _("clicks")) ?>)</small>
  </td>
 </tr>
</table>
