.horde-form table {
    width: auto;
}

.trean-favicon-container {
    float: left;
    width: 20px;
    height: 20px;
    margin: 2px;
}
.trean-favicon {
    max-width: 20px;
    max-height: 20px;
}

.trean-bookmarks-date {
    white-space: nowrap;
}
.trean-bookmarks-title {
    text-overflow: ellipsis;
    overflow: hidden;
}
.trean-bookmarks-clicks {
    text-align: center;
}

.trean-bookmarks-actions form {
    display: inline;
}

#trean-browser-instructions {
    margin: 10px;
    padding: 10px;
}

.trean-tags-related, .trean-tags-browsing {
    padding-bottom: 12px;
    padding-left: 5px;
}

.horde-tags li a img {
    padding-left: 5px;
}

.treanBookmarkTag:hover {
    background: #bbcbff;
    cursor: pointer;
}

/* Sidebar images. */
.trean-browse {
    background-image: url("graphics/trean.png");
}
.trean-tag {
    background-image: url("graphics/tag.png");
}

.treanACBox {
  background: #ebeff0;
  border: 1px solid #d0d0d0;
  cursor: default;
  text-align: left;
}
